# **A**dvanced and **N**eat **T**echniques for the **A**ccurate **R**etrieval of **E**xoplanetary and **S**tellar **S**pectra

Read the documentation [here](https://obswww.unige.ch/~bourriev/antaress/doc/html/).

## Contributors
Omar Attia, Romain Allart, Khaled Al Moulla, Vincent Bourrier, Heather Cegla, Michaël Cretignier, William Dethier, Jean-Baptiste Delisle, Xavier Dumusque, David Ehrenreich, Erik Fridén, Nathan Hara, Christophe Lovis, Samson Jules Mercier, Dany Mounzer, Francesco Alfonso Pepe, Julia Victoria Seidel, Michal Steiner, Sara Tavella, Valentina Vaulato, Theo Vrignaud, Aurélien Wyttenbach.

## References
TBD

## Contribute
You are welcome to open issues and/or contribute code via pull-requests after signing in to your [SWITCH edu-ID account](https://gitlab.unige.ch).
If you do not have an account, [create one](https://eduid.ch) and then [sign in](https://gitlab.unige.ch) by selecting "SWITCH edu-ID" as your organisation.

You can contact [Vincent Bourrier](mailto:vincent.bourrier@unige.ch) if you are interested in collaborations and developments of this project. 

